<?php
if (!isset($gCms)) exit;

if (! $this->CheckPermission('Use MetaMax')) {
  return $this->DisplayErrorPage($id, $params, $returnid,$this->Lang('accessdenied'));
}

$this->SetPreference('stylesheet_title',
		     (isset($params['stylesheet_title'])?'1':'0'));

$this->SetPreference('stylesheet_name', $params['stylesheet_name']);

$this->SetPreference('stylesheet_nocombine',
		     (isset($params['stylesheet_nocombine'])?'1':'0'));

$this->SetPreference('stylesheet_nolinks',
		     (isset($params['stylesheet_nolinks'])?'1':'0'));

$this->SetPreference('stylesheet_https',
		     (isset($params['stylesheet_https'])?'1':'0'));

$this->SetPreference('stylesheet_templateid', $params['stylesheet_templateid']);

$this->SetPreference('stylesheet_media', $params['stylesheet_media']);

$params = array('tab_message'=> 'prefsupdated', 'active_tab' => 'css');
$this->Redirect($id, 'defaultadmin', '', $params);
?>